import { Component, EventEmitter, Input, Output } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./services/image-loader.service";
import * as i2 from "./services/image-loader-config.service";
import * as i3 from "@ionic/angular";
import * as i4 from "@angular/common";
function IonicImageLoaderComponent_ion_spinner_0_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "ion-spinner", 1);
} if (rf & 2) {
    var ctx_r0 = i0.ɵɵnextContext();
    i0.ɵɵproperty("name", ctx_r0.spinnerName)("color", ctx_r0.spinnerColor);
} }
var _c0 = ["*"];
var propMap = {
    display: 'display',
    height: 'height',
    width: 'width',
    backgroundSize: 'background-size',
    backgroundRepeat: 'background-repeat',
};
var IonicImageLoaderComponent = /** @class */ (function () {
    function IonicImageLoaderComponent(_element, renderer, imageLoader, config) {
        this._element = _element;
        this.renderer = renderer;
        this.imageLoader = imageLoader;
        this.config = config;
        /**
         * Fallback URL to load when the image url fails to load or does not exist.
         */
        this.fallbackUrl = this.config.fallbackUrl;
        /**
         * Whether to show a spinner while the image loads
         */
        this.spinner = this.config.spinnerEnabled;
        /**
         * Whether to show the fallback image instead of a spinner while the image loads
         */
        this.fallbackAsPlaceholder = this.config.fallbackAsPlaceholder;
        /**
         * Attributes to pass through to img tag if _useImg == true
         */
        this.imgAttributes = [];
        /**
         * Enable/Disable caching
         */
        this.cache = true;
        /**
         * Width of the image. This will be ignored if using useImg.
         */
        this.width = this.config.width;
        /**
         * Height of the image. This will be ignored if using useImg.
         */
        this.height = this.config.height;
        /**
         * Display type of the image. This will be ignored if using useImg.
         */
        this.display = this.config.display;
        /**
         * Background size. This will be ignored if using useImg.
         */
        this.backgroundSize = this.config.backgroundSize;
        /**
         * Background repeat. This will be ignored if using useImg.
         */
        this.backgroundRepeat = this.config.backgroundRepeat;
        /**
         * Name of the spinner
         */
        this.spinnerName = this.config.spinnerName;
        /**
         * Color of the spinner
         */
        this.spinnerColor = this.config.spinnerColor;
        /**
         * Notify on image load..
         */
        this.load = new EventEmitter();
        /**
         * Indicates if the image is still loading
         */
        this.isLoading = true;
        this._useImg = this.config.useImg;
    }
    Object.defineProperty(IonicImageLoaderComponent.prototype, "useImg", {
        /**
         * Use <img> tag
         */
        set: function (val) {
            this._useImg = val !== false;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IonicImageLoaderComponent.prototype, "noCache", {
        /**
         * Convenience attribute to disable caching
         */
        set: function (val) {
            this.cache = val !== false;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IonicImageLoaderComponent.prototype, "src", {
        get: function () {
            return this._src;
        },
        /**
         * The URL of the image to load.
         */
        set: function (imageUrl) {
            this._src = this.processImageUrl(imageUrl);
            this.updateImage(this._src);
        },
        enumerable: false,
        configurable: true
    });
    IonicImageLoaderComponent.prototype.ngOnInit = function () {
        if (this.fallbackAsPlaceholder && this.fallbackUrl) {
            this.setImage(this.fallbackUrl, false);
        }
        if (!this.src) {
            // image url was not passed
            // this can happen when [src] is set to a variable that turned out to be undefined
            // one example could be a list of users with their profile pictures
            // in this case, it would be useful to use the fallback image instead
            // if fallbackUrl was used as placeholder we do not need to set it again
            if (!this.fallbackAsPlaceholder && this.fallbackUrl) {
                // we're not going to cache the fallback image since it should be locally saved
                this.setImage(this.fallbackUrl);
            }
            else {
                this.isLoading = false;
            }
        }
    };
    IonicImageLoaderComponent.prototype.updateImage = function (imageUrl) {
        var _this = this;
        this.imageLoader
            .getImagePath(imageUrl)
            .then(function (url) { return _this.setImage(url); })
            .catch(function (error) { return _this.setImage(_this.fallbackUrl || imageUrl); });
    };
    /**
     * Gets the image URL to be loaded and disables caching if necessary
     */
    IonicImageLoaderComponent.prototype.processImageUrl = function (imageUrl) {
        if (this.cache === false) {
            // need to disable caching
            if (imageUrl.indexOf('?') < 0) {
                // add ? if doesn't exists
                imageUrl += '?';
            }
            else {
                imageUrl += '&';
            }
            // append timestamp at the end to make URL unique
            imageUrl += 'cache_buster=' + Date.now();
        }
        return imageUrl;
    };
    /**
     * Set the image to be displayed
     * @param imageUrl image src
     * @param stopLoading set to true to mark the image as loaded
     */
    IonicImageLoaderComponent.prototype.setImage = function (imageUrl, stopLoading) {
        var _this = this;
        if (stopLoading === void 0) { stopLoading = true; }
        this.isLoading = !stopLoading;
        if (this._useImg) {
            // Using <img> tag
            if (!this.element) {
                // create img element if we dont have one
                this.element = this.renderer.createElement('img');
                this.renderer.appendChild(this._element.nativeElement, this.element);
            }
            // set it's src
            this.renderer.setAttribute(this.element, 'src', imageUrl);
            // if imgAttributes are defined, add them to our img element
            this.imgAttributes.forEach(function (attribute) {
                _this.renderer.setAttribute(_this.element, attribute.element, attribute.value);
            });
            if (this.fallbackUrl && !this.imageLoader.nativeAvailable) {
                this.renderer.listen(this.element, 'error', function () {
                    return _this.renderer.setAttribute(_this.element, 'src', _this.fallbackUrl);
                });
            }
        }
        else {
            // Not using <img> tag
            this.element = this._element.nativeElement;
            for (var prop in propMap) {
                if (this[prop]) {
                    this.renderer.setStyle(this.element, propMap[prop], this[prop]);
                }
            }
            this.renderer.setStyle(this.element, 'background-image', "url(\"".concat(imageUrl || this.fallbackUrl, "\")"));
        }
        if (stopLoading) {
            this.load.emit(this);
        }
    };
    IonicImageLoaderComponent.ɵfac = function IonicImageLoaderComponent_Factory(t) { return new (t || IonicImageLoaderComponent)(i0.ɵɵdirectiveInject(i0.ElementRef), i0.ɵɵdirectiveInject(i0.Renderer2), i0.ɵɵdirectiveInject(i1.ImageLoaderService), i0.ɵɵdirectiveInject(i2.ImageLoaderConfigService)); };
    IonicImageLoaderComponent.ɵcmp = /*@__PURE__*/ i0.ɵɵdefineComponent({ type: IonicImageLoaderComponent, selectors: [["img-loader"]], inputs: { fallbackUrl: "fallbackUrl", spinner: "spinner", fallbackAsPlaceholder: "fallbackAsPlaceholder", imgAttributes: "imgAttributes", cache: "cache", width: "width", height: "height", display: "display", backgroundSize: "backgroundSize", backgroundRepeat: "backgroundRepeat", spinnerName: "spinnerName", spinnerColor: "spinnerColor", useImg: "useImg", noCache: "noCache", src: "src" }, outputs: { load: "load" }, ngContentSelectors: _c0, decls: 2, vars: 1, consts: [[3, "name", "color", 4, "ngIf"], [3, "name", "color"]], template: function IonicImageLoaderComponent_Template(rf, ctx) { if (rf & 1) {
            i0.ɵɵprojectionDef();
            i0.ɵɵtemplate(0, IonicImageLoaderComponent_ion_spinner_0_Template, 1, 2, "ion-spinner", 0);
            i0.ɵɵprojection(1);
        } if (rf & 2) {
            i0.ɵɵproperty("ngIf", ctx.spinner && ctx.isLoading && !ctx.fallbackAsPlaceholder);
        } }, dependencies: [i3.IonSpinner, i4.NgIf], styles: ["ion-spinner[_ngcontent-%COMP%] { float: none; margin-left: auto; margin-right: auto; display: block; }"] });
    return IonicImageLoaderComponent;
}());
export { IonicImageLoaderComponent };
(function () { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(IonicImageLoaderComponent, [{
        type: Component,
        args: [{ selector: 'img-loader', template: "\n    <ion-spinner\n        *ngIf=\"spinner && isLoading && !fallbackAsPlaceholder\"\n        [name]=\"spinnerName\"\n        [color]=\"spinnerColor\"\n    ></ion-spinner>\n    <ng-content></ng-content>\n  ", styles: ["ion-spinner { float: none; margin-left: auto; margin-right: auto; display: block; }"] }]
    }], function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i1.ImageLoaderService }, { type: i2.ImageLoaderConfigService }]; }, { fallbackUrl: [{
            type: Input
        }], spinner: [{
            type: Input
        }], fallbackAsPlaceholder: [{
            type: Input
        }], imgAttributes: [{
            type: Input
        }], cache: [{
            type: Input
        }], width: [{
            type: Input
        }], height: [{
            type: Input
        }], display: [{
            type: Input
        }], backgroundSize: [{
            type: Input
        }], backgroundRepeat: [{
            type: Input
        }], spinnerName: [{
            type: Input
        }], spinnerColor: [{
            type: Input
        }], load: [{
            type: Output
        }], useImg: [{
            type: Input
        }], noCache: [{
            type: Input
        }], src: [{
            type: Input
        }] }); })();
//# sourceMappingURL=ionic-image-loader.component.js.map